[manpage_begin telnet n 2.0.0]
[copyright {2000-2004 by Todd J Martin <todd.martin@acm.org>}]
[moddesc {Telnet Client}]
[titledesc {A pure Tcl telnet client}]
[require Tcl 8.0]
[require telnet 2.0.0]

[description]

This package provides a pure Tcl telnet client.  This client is suitable for
interfacing to any standard telnet server.  It will automatically handle any
negotiation of telnet options.  This client will negotiate the TERM, TSPEED,
and SGA options.  It will send DONT or WONT for any other telnet options.

[list_begin definitions]

[call [cmd telnet::open] [arg host] [arg port]]

This command opens the telnet connection to the [arg host] at the specified [arg port].
The [arg host] argument can be any value that is valid for the host argument to the
[fun socket] command.

This command returns the channel identifier representing the TCP socket.  This
channel identifier can be used with [fun fconfigure] to set options on the
channel.  This identifier should be closed with the normal [fun close]
command.

[call [cmd telnet::read] [opt [arg -nonewline]] [arg channelId] [arg numChars]]

This command reads data from the telnet server.  Any embedded telnet commands
in the stream are removed, with an appropriate response being sent back to the
server.  The [arg -nonewline] and [arg numChars] arguments are passed to the
underlying [fun read] command.  The [arg channelId] is the channel identifier
returned by a previous call to [fun telnet::open].

[call [cmd telnet::write] [arg channelId] [arg string]]

This command takes the data in [arg string], performs any necessary escaping
of telnet commands and sends the processed data to the server.  The 
[arg channelId] is the channel identifier returned by a previous call to 
[fun telnet::open].

[list_end]

[section {EXAMPLE}]
For an example of how to use this package, see the telnet_test.tcl
file that is part of the tclTelnet distribution.  This file implements a
simple interactive telnet client.

[section {LIMITATIONS}]
[para]
[fun telnet::open] does not provide any way to pass options to the [fun socket]
command.  There is no way to open the socket asynchronously or specify the
local address and port.

[para]
There is no way to influence the negotiation of telnet options.

[see_also socket read fconfigure socket]
[manpage_end]
