#!/usr/bin/tclsh
# Copyright (c) 2000 by Todd J Martin <todd.martin@acm.org>
# $Id: telnet_test.tcl,v 1.13 2004/12/15 05:10:23 todd Exp $
#
# This file is used to for testing the telnet library.  It can also serve as
# an example of how to use the library.  The file implements a very simple
# telnet client in pure tcl.

lappend auto_path [pwd]
package require telnet

if { $argc != 2 } {
    puts "Wrong number of args"
    puts "Usage: telnet_test.tcl host port"
    exit 1
}
set host [lindex $argv 0]
set port [lindex $argv 1]

set ttyBuffer {}
proc readTty {tty} {
    if {[catch {set input [read $tty]} err]} {
	error $err $::errorInfo
    }
    append ::ttyBuffer $input
    set ::telnetEvent readTty
}

proc readStdin {} {
    if {[eof $pt]} {
      set ::telnetEvent EOF
      return
    }
    if {[catch {set input [gets stdin]} err]} {
	error $err $::errorInfo
    }
    append ::ttyBuffer $input
    set ::telnetEvent readStdin
}

proc tcpRead {pt} {
    if {[eof $pt]} {
      set ::telnetEvent EOF
      return
    }
    append ::telnetBuffer [telnet::read $pt]
    set ::telnetEvent tcpRead
}

set pt [telnet::open $host $port]
fconfigure $pt -blocking false -buffering none
fileevent $pt readable [list tcpRead $pt]

if {[string match $tcl_platform(platform) "unix"]} {
    close stdin
    set tty [open /dev/tty r]
    exec stty icanon brkint min 1 time 0 -istrip -ixon -ixoff -icanon -echo < /dev/tty
    fconfigure $tty -blocking false -buffering none
    fileevent $tty readable [list readTty $tty]
} else {
    fileevent stdin readable [list readStdin]
}

fconfigure stdout -buffering none
while {1} {
    set telnetEvent {}
    vwait telnetEvent
    if {[string equal $telnetEvent "tcpRead"]} {
	puts -nonewline "$telnetBuffer"
	set telnetBuffer {}
    } elseif {[string equal $telnetEvent "readTty"] || \
	      [string equal $telnetEvent "readStdin"] } {
	if {[catch {telnet::write $pt $ttyBuffer} err]} {
	    # Must be shutting down the connection
	    break
	}
	set ttyBuffer {}
    } elseif {[string equal $telnetEvent "EOF"]} {
	break
    }
}
close $pt
